==> applet-tencent-0.0.3-sources.jar: cn/sinozg/applet/biz/system/service/impl/TencentServiceImpl.java <==
package cn.sinozg.applet.biz.system.service.impl;

import cn.sinozg.applet.biz.system.service.TencentCbService;
import cn.sinozg.applet.biz.system.service.TencentService;
import cn.sinozg.applet.biz.system.vo.request.TencentMessageRequest;
import cn.sinozg.applet.biz.system.vo.request.TencentServiceRequest;
import cn.sinozg.applet.common.properties.AppValue;
import cn.sinozg.applet.common.utils.CypherUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author: xyb
 * @Description:
 * @Date: 2023-03-23 下午 05:49
 **/
@Service
public class TencentServiceImpl implements TencentService {


    @Resource
    private AppValue app;

    @Resource
    private TencentCbService service;

    private final Logger log = LoggerFactory.getLogger(TencentServiceImpl.class);
    @Override
    public String receiveGet(TencentServiceRequest params) {
        log.info("get receive signature {}, timestamp {} , nonce {}, , echostr {}", params.getSignature(), params.getTimestamp()
                , params.getNonce(), params.getEchostr());
        boolean success = CypherUtil.signature(false, params.getSignature(), params.getTimestamp(), params.getNonce(), app.getWechat().getMsgToken());
        return success ? params.getEchostr() : StringUtils.EMPTY;
    }

    @Override
    public TencentMessageRequest receivePost(TencentMessageRequest params) {
        return service.wechatMessage(params);
    }
}

==> applet-tencent-3.0.0-sources.jar: cn/sinozg/applet/biz/system/service/impl/TencentServiceImpl.java <==
package cn.sinozg.applet.biz.system.service.impl;

import cn.sinozg.applet.biz.system.service.TencentCbService;
import cn.sinozg.applet.biz.system.service.TencentService;
import cn.sinozg.applet.biz.system.vo.request.TencentMessageRequest;
import cn.sinozg.applet.biz.system.vo.request.TencentServiceRequest;
import cn.sinozg.applet.common.properties.AppValue;
import cn.sinozg.applet.common.utils.CypherUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import jakarta.annotation.Resource;

/**
 * @Author: xyb
 * @Description:
 * @Date: 2023-03-23 下午 05:49
 **/
@Service
public class TencentServiceImpl implements TencentService {


    @Resource
    private AppValue app;

    @Resource
    private TencentCbService service;

    private final Logger log = LoggerFactory.getLogger(TencentServiceImpl.class);
    @Override
    public String receiveGet(TencentServiceRequest params) {
        log.info("get receive signature {}, timestamp {} , nonce {}, , echostr {}", params.getSignature(), params.getTimestamp()
                , params.getNonce(), params.getEchostr());
        boolean success = CypherUtil.signature(false, params.getSignature(), params.getTimestamp(), params.getNonce(), app.getWechat().getMsgToken());
        return success ? params.getEchostr() : StringUtils.EMPTY;
    }

    @Override
    public TencentMessageRequest receivePost(TencentMessageRequest params) {
        return service.wechatMessage(params);
    }
}
